@@ -8,7 +8,7 @@ from uuid import UUID
 from grpc import RpcError
 
 from preseem import NetworkMetadataReference
-from preseem.source_model import Olt, Router, Service
+from preseem.source_model import AccessPoint, Olt, Router, Service
 from preseem_protobuf.model.service_pb2 import SetAttachmentReq
 
 # STM-6039 Only allow the sync to run once at a time, to prevent duplicate
@@ -188,6 +188,7 @@ async def sync_preseem_model(preseem_model,
                              services=None,
                              routers=None,
                              olts=None,
+                             aps=None,
                              nm_model=None,
                              deactivate=None,
                              noact=False,
@@ -205,7 +206,9 @@ async def sync_preseem_model(preseem_model,
 
     assert isinstance(company_uuid, bytes)
     assert isinstance(source, str)
-    assert isinstance(role, UUID)
+    if role:
+        # PPA-1512 pass role=None to disable the old AP sync method.
+        assert isinstance(role, UUID)
 
     if source == '':
         raise ValueError('source cannot be the empty string')
@@ -228,8 +231,9 @@ async def sync_preseem_model(preseem_model,
                 discs = role_discs[disc.intent_role_uuid] = []
             discs.append(disc)
 
-        model_discs = {x.uuid: x for x in role_discs.get(role.bytes) or []}
-        disc_ids = {(x.source, x.source_id): x for x in model_discs.values()}
+        if role:
+            model_discs = {x.uuid: x for x in role_discs.get(role.bytes) or []}
+            disc_ids = {(x.source, x.source_id): x for x in model_discs.values()}
 
         # Create a map of name -> site.  Handle multiple sites with the same
         # name by preferring active sites, then taking the first sorted uuid.
@@ -281,75 +285,78 @@ async def sync_preseem_model(preseem_model,
                 if site:
                     model_sites[site.uuid] = site_names[site_name] = site
 
-        unref_discs = set([x[0] for x in model_discs.items() if x[1].source == source])
         uuid_map = {}
-        for item in items:
-            host = str(ip_address(item.host))  # validate ip address
-            key = (source, item.id)
-            disc = disc_ids.get(key)
-            if disc:
-                uuid_map[item.id] = UUID(bytes=disc.uuid)
-                unref_discs.remove(disc.uuid)
-                site = model_sites.get(disc.site_uuid) if disc.site_uuid else None
-                changes = []
-                mods = {}
-                if disc.inactive:
-                    changes.append('reactivated')
-                    mods['inactive'] = False
-                    mods['element_uuid'] = None  # STM-9823
-                if disc.name != item.name:
-                    changes.append(f'name: {disc.name} -> {item.name}')
-                    mods['name'] = item.name
-                if disc.management_ip != host:
-                    changes.append(f'management_ip: {disc.management_ip} -> {host}')
-                    mods['management_ip'] = host
-                if site.name != item.site:
-                    changes.append(f'site: {site.name} -> {item.site}')
-                    mods['site_uuid'] = site_names[item.site].uuid
-                if mods:
-                    logging.info('sync_preseem_model(%s): modify %s (%s)', source, item,
-                                 ','.join(changes))
+        if role:  # old algorithm
+            unref_discs = set(
+                [x[0] for x in model_discs.items() if x[1].source == source])
+            for item in items:
+                host = str(ip_address(item.host))  # validate ip address
+                key = (source, item.id)
+                disc = disc_ids.get(key)
+                if disc:
+                    uuid_map[item.id] = UUID(bytes=disc.uuid)
+                    unref_discs.remove(disc.uuid)
+                    site = model_sites.get(disc.site_uuid) if disc.site_uuid else None
+                    changes = []
+                    mods = {}
+                    if disc.inactive:
+                        changes.append('reactivated')
+                        mods['inactive'] = False
+                        mods['element_uuid'] = None  # STM-9823
+                    if disc.name != item.name:
+                        changes.append(f'name: {disc.name} -> {item.name}')
+                        mods['name'] = item.name
+                    if disc.management_ip != host:
+                        changes.append(f'management_ip: {disc.management_ip} -> {host}')
+                        mods['management_ip'] = host
+                    if site.name != item.site:
+                        changes.append(f'site: {site.name} -> {item.site}')
+                        mods['site_uuid'] = site_names[item.site].uuid
+                    if mods:
+                        logging.info('sync_preseem_model(%s): modify %s (%s)', source,
+                                     item, ','.join(changes))
+                        if not noact:
+                            if nm_model and 'reactivated' in changes and disc.element_uuid:
+                                # STM-9823 as part of clearing the element_uuid,
+                                # we also need to delete the elem_discovery ref.
+                                ref = NetworkMetadataReference(
+                                    'elem_discovery', str(UUID(bytes=disc.uuid)), {})
+                                logging.info(' delete reference: %s', ref)
+                                await nm_model.del_ref(ref)
+                            await call_and_log_error(
+                                preseem_model.Element.UpdateElementDiscovery(
+                                    company_uuid=company_uuid, uuid=disc.uuid, **mods))
+
+                else:
+                    logging.info('sync_preseem_model(%s): create %s', source, item)
+                    if not noact:
+                        site_uuid = site_names[item.site].uuid
+                        disc = await call_and_log_error(
+                            preseem_model.Element.CreateElementDiscovery(
+                                company_uuid=company_uuid,
+                                name=item.name,
+                                management_ip=item.host,
+                                site_uuid=site_uuid,
+                                source=source,
+                                source_id=item.id,
+                                intent_role_uuid=role.bytes))
+                        if disc:
+                            uuid = UUID(bytes=disc.uuid)
+                            logging.info(
+                                'sync_preseem_model(%s): created ElementDiscovery "%s"',
+                                source, uuid)
+                            uuid_map[item.id] = uuid
+            for disc_uuid in unref_discs:
+                disc = model_discs.get(disc_uuid)
+                if not disc.inactive:
+                    logging.info("sync_preseem_model(%s): deactivate %s", source,
+                                 UUID(bytes=disc_uuid))
                     if not noact:
-                        if nm_model and 'reactivated' in changes and disc.element_uuid:
-                            # STM-9823 as part of clearing the element_uuid,
-                            # we also need to delete the elem_discovery ref.
-                            ref = NetworkMetadataReference('elem_discovery',
-                                                           str(UUID(bytes=disc.uuid)),
-                                                           {})
-                            logging.info(' delete reference: %s', ref)
-                            await nm_model.del_ref(ref)
                         await call_and_log_error(
                             preseem_model.Element.UpdateElementDiscovery(
-                                company_uuid=company_uuid, uuid=disc.uuid, **mods))
-
-            else:
-                logging.info('sync_preseem_model(%s): create %s', source, item)
-                if not noact:
-                    site_uuid = site_names[item.site].uuid
-                    disc = await call_and_log_error(
-                        preseem_model.Element.CreateElementDiscovery(
-                            company_uuid=company_uuid,
-                            name=item.name,
-                            management_ip=item.host,
-                            site_uuid=site_uuid,
-                            source=source,
-                            source_id=item.id,
-                            intent_role_uuid=role.bytes))
-                    if disc:
-                        uuid = UUID(bytes=disc.uuid)
-                        logging.info(
-                            'sync_preseem_model(%s): created ElementDiscovery "%s"',
-                            source, uuid)
-                        uuid_map[item.id] = uuid
-        for disc_uuid in unref_discs:
-            disc = model_discs.get(disc_uuid)
-            if not disc.inactive:
-                logging.info("sync_preseem_model(%s): deactivate %s", source,
-                             UUID(bytes=disc_uuid))
-                if not noact:
-                    await call_and_log_error(
-                        preseem_model.Element.UpdateElementDiscovery(
-                            company_uuid=company_uuid, uuid=disc_uuid, inactive=True))
+                                company_uuid=company_uuid,
+                                uuid=disc_uuid,
+                                inactive=True))
         new_packages = []
         if packages is not None:
             assert isinstance(packages, dict)
@@ -472,7 +479,7 @@ async def sync_preseem_model(preseem_model,
                                 deactivate=deactivate is not False,
                                 noact=noact)
 
-        for bss_objs, source_type in (routers, Router), (olts, Olt):
+        for bss_objs, source_type in (aps, AccessPoint), (routers, Router), (olts, Olt):
             if bss_objs is not None:
                 assert isinstance(bss_objs, dict)
                 new_sites = set()
