@@ -2469,6 +2469,17 @@ class NetworkElement(BaseWrapperClass):
         else:
             self.pb.ClearField('extra')
 
+    @property
+    def counter_source(self):
+        return self.pb.counter_source if self.pb.HasField('counter_source') else None
+
+    @counter_source.setter
+    def counter_source(self, value):
+        if value is not None:
+            self.pb.counter_source = value
+        else:
+            self.pb.ClearField('counter_source')
+
 
 @pb_wrapper(network_poller_pb2.NetworkElementUpdate)
 class NetworkElementUpdate(BaseWrapperClass):
