@@ -385,6 +385,14 @@ class TestNetworkElementUpdate(unittest.TestCase):
         ne.extra = None
         self.assertEqual(ne.extra, None)
 
+        self.assertEqual(ne.counter_source, None)
+        ne.counter_source = "http"
+        self.assertEqual(ne.counter_source, "http")
+        ne.counter_source = None
+        self.assertEqual(ne.counter_source, None)
+        ne.counter_source = "snmp"
+        self.assertEqual(ne.counter_source, "snmp")
+
         # Interface
         intf = ne.interfaces.add()
         intf.id = '1'
