@@ -3,8 +3,8 @@ import unittest
 from hashlib import sha256
 from uuid import uuid4
 
-from preseem.source_model import Attachment, Olt, Router, Account, Service
-from preseem.grpc_nm_model import NetworkMetadataReference
+from preseem.source_model import Attachment, AccessPoint, Olt, Router, Account, Service, Site
+from preseem.grpc_nm_model import NetworkMetadataEntity, NetworkMetadataReference
 from preseem_protobuf.model.account_pb2 import AccountStatus
 from preseem_protobuf.model.common_pb2 import AccountType
 
@@ -133,6 +133,27 @@ class TestSourceModel(unittest.TestCase):
         olt._uuid = uuid.bytes
         self.assertEqual(olt.get_nm('test'), [ref])
 
+    def test_ap(self):
+        """Simple unit test for AP, the code is shared with Router so most of the
+           testing is done there; the main difference is the expanded set of network
+           metadata used for APs."""
+        ap = AccessPoint("ap1", name='AP 1', host='192.0.2.2', site='Site 1')
+        ref = NetworkMetadataReference(type='ap', value='ap1', attributes={'ip_address': '192.0.2.2', 'topology1': 'AP 1', 'topology2': 'Site 1', 'system': 'test', 'topology1_snmp': 'ap1', 'ap_config': 'ap1'})
+        uuid = uuid4()
+        ref.attributes['uuid'] = str(uuid)
+        ap._uuid = uuid.bytes
+        nms = ap.get_nm('test')
+
+        self.assertEqual(len(nms), 3)
+        ap_ref = next((x for x in nms if isinstance(x, NetworkMetadataReference) and x.type == 'ap'), None)
+        self.assertEqual(ap_ref, ref)
+        ref = NetworkMetadataReference('session', '192.0.2.2', {'service_rate_down': 10000000, 'service_rate_up': 10000000, 'subscriber_identifier': '192.0.2.2', 'subscriber_name': 'AP 1', 'system': 'test'})
+        session_ref = next((x for x in nms if isinstance(x, NetworkMetadataReference) and x.type == 'session'), None)
+        self.assertEqual(session_ref, ref)
+        entity = next((x for x in nms if isinstance(x, NetworkMetadataEntity)), None)
+        self.assertEqual(entity.network_prefix, '192.0.2.2')
+        self.assertEqual(entity.attributes, {'session': '192.0.2.2', 'snmp_session': '192.0.2.2'})
+
     def test_account_id(self):
         """Test field checking of account.id"""
         with self.assertRaises(TypeError):
@@ -688,3 +709,47 @@ class TestSourceModel(unittest.TestCase):
         attachment2.network_prefixes.append(ip1)
 
         self.assertEqual(attachment1, attachment2)
+
+    def test_site_id(self):
+        """Test field checking of site.id"""
+        with self.assertRaises(TypeError):
+            Site()  # id is required
+        with self.assertRaises(ValueError):
+            Site(None)  # id can't be None
+        with self.assertRaises(ValueError):
+            Site("")  # id can't be empty string
+        site = Site(123)
+        self.assertEqual(site.id, "123")  # int converted to string
+        site = Site(0)
+        self.assertEqual(site.id, "0")  # int converted to string
+        site = Site("my_id")
+        with self.assertRaises(AttributeError):
+            site.id = "new_id"  # id is immutable once set
+
+    def test_site_name(self):
+        """Test field checking of site.name"""
+        site = Site("a1", name=None)
+        self.assertEqual(site.name, None)
+        site = Site("a1", name="")
+        self.assertError(site, 'name', '')  # name can't be empty
+        site = Site("a1", name='site 1')
+        self.assertEqual(site.name, 'site 1')
+        site.name = 123
+        self.assertError(site, 'name', 123)  # name must be a string
+        self.assertEqual(site.name, 'site 1')
+        site.name = 'site 2'
+        self.assertEqual(site.name, 'site 2')
+        site.name = None
+        self.assertEqual(site.name, None)
+
+    def test_site_network_prefixes(self):
+        """Test field checking of site.network_prefixes"""
+        site = Site('s1')
+        self.assertEqual(site.network_prefixes, [])
+        site = Site('s1', network_prefixes=None)
+        self.assertEqual(site.network_prefixes, [])
+        with self.assertRaises(TypeError):
+            site.network_prefixes = ''  # must be a list
+        site.network_prefixes.append('192.0.2.1')
+        self.assertEqual(site.network_prefixes[0], '192.0.2.1')
+
